//
//  ContactsTableViewController.m
//  PhoneBook
//
//  Created by Santiago Pavón on 30/10/13.
//  Copyright (c) 2013 UPM. All rights reserved.
//

#import "ContactsTableViewController.h"
#import "EditContactViewController.h"

#import "Contact.h"
#import "ContactBook.h"
#import "ContactCell.h"

@interface ContactsTableViewController ()

@property (nonatomic,strong) ContactBook * contactBook;

@end

@implementation ContactsTableViewController

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];

    // Uncomment the following line to preserve selection between presentations.
    // self.clearsSelectionOnViewWillAppear = NO;
 
    // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
    self.navigationItem.leftBarButtonItem = self.editButtonItem;
    
    if (! self.contactBook) {
        self.contactBook = [[ContactBook alloc] init];
    }
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}



#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [self.contactBook.contacts count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Contact Cell";
    
    ContactCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier
                                                            forIndexPath:indexPath];
  
    Contact * contact = self.contactBook.contacts[indexPath.row];
    
    cell.nameLabel.text = contact.name;
    cell.addressLabel.text = contact.address;
    cell.phoneLabel.text = contact.phone;
    
    return cell;
}


/*
// Override to support conditional editing of the table view.
- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the specified item to be editable.
    return YES;
}
*/


// Override to support editing the table view.
- (void)  tableView:(UITableView *)tableView
 commitEditingStyle:(UITableViewCellEditingStyle)editingStyle
  forRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        
        [self.contactBook.contacts removeObjectAtIndex:indexPath.row];
        
        [tableView deleteRowsAtIndexPaths:@[indexPath]
                         withRowAnimation:UITableViewRowAnimationFade];
    }   
    else if (editingStyle == UITableViewCellEditingStyleInsert) {
        // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
    }   
}


/*
// Override to support rearranging the table view.
- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)fromIndexPath toIndexPath:(NSIndexPath *)toIndexPath
{
}
*/

/*
// Override to support conditional rearranging of the table view.
- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the item to be re-orderable.
    return YES;
}
*/





#pragma mark - Navigation


- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    if ([segue.identifier isEqualToString:@"Editing Contact"]) {
        EditContactViewController *ecvc = segue.destinationViewController;
        
        NSIndexPath * ip = [self.tableView indexPathForSelectedRow];
        
        ecvc.contact = self.contactBook.contacts[ip.row];
        
    } else if ([segue.identifier isEqualToString:@"Adding Contact"]) {
        
        EditContactViewController *ecvc = segue.destinationViewController;
        
        Contact * contact = [[Contact alloc] initWithName:@""
                                                  address:@""
                                                    phone:@""];
        [self.contactBook.contacts insertObject:contact atIndex:0];
        
        NSIndexPath * ip = [NSIndexPath indexPathForRow:0 inSection:0];
        
        [self.tableView insertRowsAtIndexPaths:@[ip]
                              withRowAnimation:UITableViewRowAnimationNone];
        
        [self.tableView selectRowAtIndexPath:ip
                                    animated:NO
                              scrollPosition:UITableViewScrollPositionTop];
        
        ecvc.contact = contact;
    }
}



- (IBAction) contactWasChanged:(UIStoryboardSegue*)segue
{
    NSIndexPath * ip = [self.tableView indexPathForSelectedRow];

    [self.tableView reloadRowsAtIndexPaths:@[ip]
                          withRowAnimation:YES];
}

@end














